=============
Atlas API SDK
=============


.. image:: https://img.shields.io/pypi/v/mongodb_atlas_api_sdk.svg
        :target: https://pypi.python.org/pypi/mongodb_atlas_api_sdk

Atlas Admin API SDK


* Free software: MPL-2.0


Features
--------

* DatabaseUser management (CRUD-L)
* Database User Roles / Scopes updates
